@@ -1,7 +1,7 @@
 //
 // Automated Testing Framework (atf)
 //
-// Copyright (c) 2007, 2008, 2009, 2010 The NetBSD Foundation, Inc.
+// Copyright (c) 2007, 2008, 2009, 2010, 2011 The NetBSD Foundation, Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -104,6 +104,23 @@ check_config(const std::string& variables, const atf::tests::vars_map& config)
     return "";
 }
 
+static
+std::string
+check_files(const std::string& progs)
+{
+    const std::vector< std::string > v = atf::text::split(progs, " ");
+    for (std::vector< std::string >::const_iterator iter = v.begin();
+         iter != v.end(); iter++) {
+        const atf::fs::path file(*iter);
+        if (!file.is_absolute())
+            throw std::runtime_error("Relative paths are not allowed when "
+                "checking for a required file (" + file.str() + ")");
+        if (!atf::fs::exists(file))
+            return "Required file '" + file.str() + "' not found";
+    }
+    return "";
+}
+
 static
 std::string
 check_machine(const std::string& machines)
@@ -137,7 +154,7 @@ check_progs(const std::string& progs)
 
 static
 std::string
-check_user(const std::string& user)
+check_user(const std::string& user, const atf::tests::vars_map& config)
 {
     if (user == "root") {
         if (!impl::is_root())
@@ -145,9 +162,23 @@ check_user(const std::string& user)
         else
             return "";
     } else if (user == "unprivileged") {
-        if (impl::is_root())
-            return "Requires an unprivileged user";
-        else
+        if (impl::is_root()) {
+            const atf::tests::vars_map::const_iterator iter = config.find(
+                "unprivileged-user");
+            if (iter == config.end())
+                return "Requires an unprivileged user and the "
+                    "'unprivileged-user' configuration variable is not set";
+            else {
+                const std::string& unprivileged_user = (*iter).second;
+                try {
+                    (void)impl::get_user_ids(unprivileged_user);
+                    return "";
+                } catch (const std::runtime_error& e) {
+                    return "Failed to get information for user " +
+                        unprivileged_user;
+                }
+            }
+        } else
             return "";
     } else
         throw std::runtime_error("Invalid value '" + user + "' for property "
@@ -172,12 +203,14 @@ impl::check_requirements(const atf::tests::vars_map& metadata,
             failure_reason = check_arch(value);
         else if (name == "require.config")
             failure_reason = check_config(value, config);
+        else if (name == "require.files")
+            failure_reason = check_files(value);
         else if (name == "require.machine")
             failure_reason = check_machine(value);
         else if (name == "require.progs")
             failure_reason = check_progs(value);
         else if (name == "require.user")
-            failure_reason = check_user(value);
+            failure_reason = check_user(value, config);
         else {
             // Unknown require.* properties are forbidden by the
             // application/X-atf-tp parser.
@@ -187,3 +220,29 @@ impl::check_requirements(const atf::tests::vars_map& metadata,
 
     return failure_reason;
 }
+
+std::pair< int, int >
+impl::get_required_user(const atf::tests::vars_map& metadata,
+                        const atf::tests::vars_map& config)
+{
+    const atf::tests::vars_map::const_iterator user = metadata.find(
+        "require.user");
+    if (user == metadata.end())
+        return std::make_pair(-1, -1);
+
+    if ((*user).second == "unprivileged") {
+        if (impl::is_root()) {
+            const atf::tests::vars_map::const_iterator iter = config.find(
+                "unprivileged-user");
+            try {
+                return impl::get_user_ids((*iter).second);
+            } catch (const std::exception& e) {
+                UNREACHABLE;  // This has been validated by check_user.
+                throw e;
+            }
+        } else {
+            return std::make_pair(-1, -1);
+        }
+    } else
+        return std::make_pair(-1, -1);
+}
