@@ -239,7 +239,9 @@ prepare_child(const atf::fs::path& workdir)
     atf::env::unset("LC_MONETARY");
     atf::env::unset("LC_NUMERIC");
     atf::env::unset("LC_TIME");
-    atf::env::unset("TZ");
+    atf::env::set("TZ", "UTC");
+
+    atf::env::set("__RUNNING_INSIDE_ATF_RUN", "internal-yes-value");
 
     impl::change_directory(workdir);
 }
@@ -418,6 +420,7 @@ detail::atf_tp_reader::validate_and_insert(const std::string& name,
                               ident_regex + "; was '" + value + "'");
     } else if (name == "require.arch") {
     } else if (name == "require.config") {
+    } else if (name == "require.files") {
     } else if (name == "require.machine") {
     } else if (name == "require.progs") {
     } else if (name == "require.user") {
